searchData={"content_type":"text/markdown","items":[{"doc":"JSON console back-end for Elixir Logger.\n\nIt can be used as drop-in replacement for default `:console` Logger back-end in cases where you use\nuse Google Cloud Logger or other JSON-based log collectors.","ref":"LoggerJSON.html","title":"LoggerJSON","type":"module"},{"doc":"LoggerJSON provides three JSON formatters out of the box.\n\nYou can change this structure by implementing `LoggerJSON.Formatter` behaviour and passing module\nname to `:formatter` config option. Example implementations can be found in `LoggerJSON.Formatters.GoogleCloudLogger`,\n`LoggerJSON.Formatters.DatadogLogger`, and `LoggerJSON.Formatters.BasicLogger`.\n\n    config :logger_json, :backend,\n      formatter: MyFormatterImplementation\n\nIf your formatter supports different options, you can specify them with `:formatter_opts`.\n\n    config :logger_json, :backend,\n      formatter: LoggerJSON.Formatters.DatadogLogger,\n      formatter_opts: %{hostname: \"example.com\"}","ref":"LoggerJSON.html#module-log-format","title":"Log Format - LoggerJSON","type":"module"},{"doc":"You can replace default Jason encoder with other module that supports `encode!/1` function. This can be even used\nas custom formatter callback.\n\nPopular Jason alternatives:\n\n * [poison](https://hex.pm/packages/poison).\n * [exjsx](https://github.com/talentdeficit/exjsx).\n * [elixir-json](https://github.com/cblage/elixir-json) - native Elixir encoder implementation.\n * [jiffy](https://github.com/davisp/jiffy).","ref":"LoggerJSON.html#module-encoders-support","title":"Encoders support - LoggerJSON","type":"module"},{"doc":"For dynamically configuring the endpoint, such as loading data\nfrom environment variables or configuration files, LoggerJSON provides\nan `:on_init` option that allows developers to set a module, function\nand list of arguments that is invoked when the endpoint starts. If you\nwould like to disable the `:on_init` callback function dynamically, you\ncan pass in `:disabled` and no callback function will be called.\n\n    config :logger_json, :backend,\n      on_init: {YourApp.Logger, :load_from_system_env, []}","ref":"LoggerJSON.html#module-dynamic-configuration","title":"Dynamic configuration - LoggerJSON","type":"module"},{"doc":"","ref":"LoggerJSON.html#code_change/3","title":"LoggerJSON.code_change/3","type":"function"},{"doc":"Changes Logger log level at runtime.\n\nNotice that settings this value below `compile_time_purge_level` would not work,\nbecause Logger calls would be already stripped at compile-time.","ref":"LoggerJSON.html#configure_log_level!/1","title":"LoggerJSON.configure_log_level!/1","type":"function"},{"doc":"Configures Logger log level at runtime by using value from environment variable.\n\nBy default, 'LOG_LEVEL' environment variable is used.","ref":"LoggerJSON.html#configure_log_level_from_env!/1","title":"LoggerJSON.configure_log_level_from_env!/1","type":"function"},{"doc":"","ref":"LoggerJSON.html#handle_call/2","title":"LoggerJSON.handle_call/2","type":"function"},{"doc":"","ref":"LoggerJSON.html#handle_event/2","title":"LoggerJSON.handle_event/2","type":"function"},{"doc":"","ref":"LoggerJSON.html#handle_info/2","title":"LoggerJSON.handle_info/2","type":"function"},{"doc":"","ref":"LoggerJSON.html#init/1","title":"LoggerJSON.init/1","type":"function"},{"doc":"","ref":"LoggerJSON.html#take_metadata/3","title":"LoggerJSON.take_metadata/3","type":"function"},{"doc":"","ref":"LoggerJSON.html#terminate/2","title":"LoggerJSON.terminate/2","type":"function"},{"doc":"Implements the behaviour of `Ecto.LogEntry` and sends query as a string\nto Logger with additional metadata:\n\n  * query.execution_time_μs - the time spent executing the query in microseconds;\n  * query.decode_time_μs - the time spent decoding the result in microseconds (it may be 0);\n  * query.queue_time_μs - the time spent to check the connection out in microseconds (it may be 0);\n  * query.duration_μs - time the query taken (sum of `query_time`, `decode_time` and `queue_time`);\n  * connection_pid - the connection process that executed the query;\n  * ansi_color - the color that should be used when logging the entry.\n\nFor more information see [LogEntry](https://github.com/elixir-ecto/ecto/blob/master/lib/ecto/log_entry.ex)\nsource code.","ref":"LoggerJSON.Ecto.html","title":"LoggerJSON.Ecto","type":"module"},{"doc":"Logs query string with metadata from `Ecto.LogEntry` in with debug level.","ref":"LoggerJSON.Ecto.html#log/1","title":"LoggerJSON.Ecto.log/1","type":"function"},{"doc":"Overwritten to use JSON.\n\nLogs the given entry in the given level.","ref":"LoggerJSON.Ecto.html#log/2","title":"LoggerJSON.Ecto.log/2","type":"function"},{"doc":"","ref":"LoggerJSON.Ecto.html#telemetry_logging_handler/4","title":"LoggerJSON.Ecto.telemetry_logging_handler/4","type":"function"},{"doc":"Behaviour that should be implemented by log formatters.\n\nExample implementations can be found in `LoggerJSON.Formatters.GoogleCloudLogger` and\n`LoggerJSON.Formatters.BasicLogger`.","ref":"LoggerJSON.Formatter.html","title":"LoggerJSON.Formatter","type":"behaviour"},{"doc":"Format event callback.\n\nReturned map will be encoded to JSON.","ref":"LoggerJSON.Formatter.html#c:format_event/6","title":"LoggerJSON.Formatter.format_event/6","type":"callback"},{"doc":"Initialization callback. Ran on startup with the given `formatter_opts` list.\n\nReturned list will be used as formatter_state in `format_event/6`.","ref":"LoggerJSON.Formatter.html#c:init/1","title":"LoggerJSON.Formatter.init/1","type":"callback"},{"doc":"This module contains functions that can be used across different\n`LoggerJSON.Formatter` implementations to provide common functionality.","ref":"LoggerJSON.FormatterUtils.html","title":"LoggerJSON.FormatterUtils","type":"module"},{"doc":"Provide a string output of the MFA log entry.","ref":"LoggerJSON.FormatterUtils.html#format_function/2","title":"LoggerJSON.FormatterUtils.format_function/2","type":"function"},{"doc":"","ref":"LoggerJSON.FormatterUtils.html#format_function/3","title":"LoggerJSON.FormatterUtils.format_function/3","type":"function"},{"doc":"Format an exception for use within a log entry.","ref":"LoggerJSON.FormatterUtils.html#format_process_crash/1","title":"LoggerJSON.FormatterUtils.format_process_crash/1","type":"function"},{"doc":"RFC3339 UTC \"Zulu\" format.","ref":"LoggerJSON.FormatterUtils.html#format_timestamp/1","title":"LoggerJSON.FormatterUtils.format_timestamp/1","type":"function"},{"doc":"Optionally put a value to a map.","ref":"LoggerJSON.FormatterUtils.html#maybe_put/3","title":"LoggerJSON.FormatterUtils.maybe_put/3","type":"function"},{"doc":"Basic JSON log formatter with no vendor specific formatting.","ref":"LoggerJSON.Formatters.BasicLogger.html","title":"LoggerJSON.Formatters.BasicLogger","type":"module"},{"doc":"[DataDog](https://www.datadoghq.com) formatter. This will adhere to the\n[default standard attribute list](https://docs.datadoghq.com/logs/processing/attributes_naming_convention/#default-standard-attribute-list)\nas much as possible.","ref":"LoggerJSON.Formatters.DatadogLogger.html","title":"LoggerJSON.Formatters.DatadogLogger","type":"module"},{"doc":"This formatter has a couple of options to fine tune the logging output for\nyour deployed environment.\n\n### `hostname`\n\nBy setting the `hostname` value, you can change how the `syslog.hostname` is\nset in logs. In most cases, you can leave this unset and it will use default\nto `:system`, which uses `:inet.gethostname/0` to resolve the value.\n\nIf you are running in an environment where the hostname is not correct, you\ncan hard code it by setting `hostname` to a string. In places where the\nhostname is inaccurate but also dynamic (like Kubernetes), you can set\n`hostname` to `:unset` to exclude it entirely. You'll then be relying on\n[`dd-agent`](https://docs.datadoghq.com/agent/) to determine the hostname.","ref":"LoggerJSON.Formatters.DatadogLogger.html#module-options","title":"Options - LoggerJSON.Formatters.DatadogLogger","type":"module"},{"doc":"Google Cloud Logger formatter.","ref":"LoggerJSON.Formatters.GoogleCloudLogger.html","title":"LoggerJSON.Formatters.GoogleCloudLogger","type":"module"},{"doc":"Builds structured payload which is mapped to Google Cloud Logger\n[`LogEntry`](https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry) format.\n\nSee: https://cloud.google.com/logging/docs/agent/configuration#special_fields_in_structured_payloads","ref":"LoggerJSON.Formatters.GoogleCloudLogger.html#format_event/6","title":"LoggerJSON.Formatters.GoogleCloudLogger.format_event/6","type":"function"},{"doc":"Google Error Reporter formatter.","ref":"LoggerJSON.Formatters.GoogleErrorReporter.html","title":"LoggerJSON.Formatters.GoogleErrorReporter","type":"module"},{"doc":"","ref":"LoggerJSON.Formatters.GoogleErrorReporter.html#report/4","title":"LoggerJSON.Formatters.GoogleErrorReporter.report/4","type":"function"},{"doc":"Utilities for converting metadata into data structures that can be safely passed to `Jason.encode!/1`.","ref":"LoggerJSON.JasonSafeFormatter.html","title":"LoggerJSON.JasonSafeFormatter","type":"module"},{"doc":"Produces metadata that is \"safe\" for calling Jason.encode!/1 on without errors.\nThis means that unexpected Logger metadata won't cause logging crashes.\n\nCurrent formatting is...\n  * Maps: as is\n  * Printable binaries: as is\n  * Numbers: as is\n  * Structs that don't implement Jason.Encoder: converted to maps\n  * Tuples: converted to lists\n  * Keyword lists: converted to Maps\n  * everything else: inspected","ref":"LoggerJSON.JasonSafeFormatter.html#format/1","title":"LoggerJSON.JasonSafeFormatter.format/1","type":"function"},{"doc":"","ref":"LoggerJSON.JasonSafeFormatter.html#jason_implemented?/1","title":"LoggerJSON.JasonSafeFormatter.jason_implemented?/1","type":"function"},{"doc":"A Plug to log request information in JSON format.","ref":"LoggerJSON.Plug.html","title":"LoggerJSON.Plug","type":"module"},{"doc":"Initializes the Plug.\n\n#","ref":"LoggerJSON.Plug.html#init/1","title":"LoggerJSON.Plug.init/1","type":"function"},{"doc":"* `:log` - log level which is used to log requests;\n  * `:version_header` - request header which is used to determine API version requested by\n  client, default: `x-api-version`;\n  * `:metadata_formatter` - module with `build_metadata/3` function that formats the metadata\n  before it's sent to logger, default - `LoggerJSON.Plug.MetadataFormatters.GoogleCloudLogger`.\n\n#","ref":"LoggerJSON.Plug.html#init/1-available-options","title":"Available options - LoggerJSON.Plug.init/1","type":"function"},{"doc":"* `LoggerJSON.Plug.MetadataFormatters.DatadogLogger` see module for logged structure;\n  * `LoggerJSON.Plug.MetadataFormatters.GoogleCloudLogger` leverages GCP LogEntry format;\n  * `LoggerJSON.Plug.MetadataFormatters.ELK` see module for logged structure.","ref":"LoggerJSON.Plug.html#init/1-available-metadata-formatters","title":"Available metadata formatters - LoggerJSON.Plug.init/1","type":"function"},{"doc":"This formatter builds a metadata which is natively supported by Datadog:\n\n  * `http` - see [DataDog](https://docs.datadoghq.com/logs/processing/attributes_naming_convention/#http-requests);\n  * `phoenix.controller` - Phoenix controller that processed the request;\n  * `phoenix.action` - Phoenix action that processed the request;","ref":"LoggerJSON.Plug.MetadataFormatters.DatadogLogger.html","title":"LoggerJSON.Plug.MetadataFormatters.DatadogLogger","type":"module"},{"doc":"Formats connection into Logger metadata:\n\n  * `connection.type` - type of connection (Sent or Chunked);\n  * `connection.method` - HTTP request method;\n  * `connection.request_path` - HTTP request path;\n  * `connection.status` - HTTP status code sent to a client;\n  * `client.user_agent` - value of `User-Agent` header;\n  * `client.ip' - value of `X-Forwarded-For` header if present, otherwise - remote IP of a connected client;\n  * `client.api_version' - version of API that was requested by a client;\n  * `node.hostname` - system hostname;\n  * `node.vm_pid` - Erlang VM process identifier;\n  * `phoenix.controller` - Phoenix controller that processed the request;\n  * `phoenix.action` - Phoenix action that processed the request;\n  * `latency_μs` - time in microseconds taken to process the request.","ref":"LoggerJSON.Plug.MetadataFormatters.ELK.html","title":"LoggerJSON.Plug.MetadataFormatters.ELK","type":"module"},{"doc":"This formatter builds a metadata which is natively supported by Google Cloud Logger:\n\n  * `httpRequest` - see [LogEntry#HttpRequest](https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry#HttpRequest);\n  * `client.api_version` - version of API that was requested by a client;\n  * `phoenix.controller` - Phoenix controller that processed the request;\n  * `phoenix.action` - Phoenix action that processed the request;\n  * `node.hostname` - node hostname;\n  * `node.vm_pid` - Erlang VM process identifier.","ref":"LoggerJSON.Plug.MetadataFormatters.GoogleCloudLogger.html","title":"LoggerJSON.Plug.MetadataFormatters.GoogleCloudLogger","type":"module"},{"doc":"This module contains functions that can be used across different\n`LoggerJSON.Plug.MetadataFormatters` implementations to provide\ncommon functionality.","ref":"LoggerJSON.PlugUtils.html","title":"LoggerJSON.PlugUtils","type":"module"},{"doc":"Grabs the client IP address from `Plug.Conn`. First we try\nto grab the client IP from the `x-forwarded-for` header.\nThen we fall back to the `conn.remote_ip` field.","ref":"LoggerJSON.PlugUtils.html#remote_ip/1","title":"LoggerJSON.PlugUtils.remote_ip/1","type":"function"},{"doc":"The MIT License (MIT)\n\nCopyright (c) 2016 Nebo #15\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"# LoggerJSON\n\n[![Build Status](https://travis-ci.org/Nebo15/logger_json.svg?branch=master)](https://travis-ci.org/Nebo15/logger_json)\n[![Coverage Status](https://coveralls.io/repos/github/Nebo15/logger_json/badge.svg?branch=master)](https://coveralls.io/github/Nebo15/logger_json?branch=master)\n[![Module Version](https://img.shields.io/hexpm/v/logger_json.svg)](https://hex.pm/packages/logger_json)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/logger_json/)\n[![Hex Download Total](https://img.shields.io/hexpm/dt/logger_json.svg)](https://hex.pm/packages/logger_json)\n[![License](https://img.shields.io/hexpm/l/logger_json.svg)](https://github.com/Nebo15/logger_json/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/Nebo15/logger_json.svg)](https://github.com/Nebo15/logger_json/commits/master)\n\nJSON console back-end for Elixir Logger.\n\nIt can be used as drop-in replacement for default `:console` Logger back-end in cases where you use Google Cloud Logger, DataDog or other JSON-based log collectors. After adding this back-end you may also be interested in [redirecting otp and sasl reports to Logger](https://hexdocs.pm/logger/Logger.html#error-logger-configuration) (see \"Error Logger configuration\" section).\n\nMinimum supported Erlang/OTP version is 20.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"LoggerJSON provides three JSON formatters out of the box and allows developers to implement a custom one.\n\n#","ref":"readme.html#log-format","title":"Log Format - Overview","type":"extras"},{"doc":"The `LoggerJSON.Formatters.BasicLogger` formatter provides a generic JSON formatted message with no vendor specific entries in the payload. A sample log entry from `LoggerJSON.Formatters.BasicLogger` looks like the following:\n\n```json\n{\n  \"time\": \"2020-04-02T11:59:06.710Z\",\n  \"severity\": \"debug\",\n  \"message\": \"hello\",\n  \"metadata\": {\n    \"user_id\": 13\n  }\n}\n```\n\n#","ref":"readme.html#basiclogger","title":"BasicLogger - Overview","type":"extras"},{"doc":"Generates JSON that is compatible with the [Google Cloud Logger LogEntry](https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry) format:\n\n```json\n{\n  \"message\": \"hello\",\n  \"logging.googleapis.com/sourceLocation\": {\n    \"file\": \"/os/logger_json/test/unit/logger_json_test.exs\",\n    \"function\": \"Elixir.LoggerJSONGoogleTest.test metadata can be configured/1\",\n    \"line\": 71\n  },\n  \"severity\": \"DEBUG\",\n  \"time\": \"2018-10-19T01:10:49.582Z\",\n  \"user_id\": 13\n}\n```\n\nNotice that GKE doesn't allow to set certain fields of the LogEntry, so support is limited. The results in Google Cloud Logger would looks something like this:\n\n```json\n{\n  \"httpRequest\": {\n    \"latency\": \"0.350s\",\n    \"remoteIp\": \"::ffff:10.142.0.2\",\n    \"requestMethod\": \"GET\",\n    \"requestPath\": \"/\",\n    \"requestUrl\": \"http://10.16.0.70/\",\n    \"status\": 200,\n    \"userAgent\": \"kube-probe/1.10+\"\n  },\n  \"insertId\": \"1g64u74fgmqqft\",\n  \"jsonPayload\": {\n    \"message\": \"\",\n    \"phoenix\": {\n      \"action\": \"index\",\n      \"controller\": \"Elixir.MyApp.Web.PageController\"\n    },\n    \"request_id\": \"2lfbl1r3m81c40e5v40004c2\",\n    \"vm\": {\n      \"hostname\": \"myapp-web-66979fc-vbk4q\",\n      \"pid\": 1\n    }\n  },\n  \"logName\": \"projects/hammer-staging/logs/stdout\",\n  \"metadata\": {\n    \"systemLabels\": {},\n    \"userLabels\": {}\n  },\n  \"operation\": {\n    \"id\": \"2lfbl1r3m81c40e5v40004c2\"\n  },\n  \"receiveTimestamp\": \"2018-10-18T14:33:35.515253723Z\",\n  \"resource\": {},\n  \"severity\": \"INFO\",\n  \"sourceLocation\": {\n    \"file\": \"iex\",\n    \"function\": \"Elixir.LoggerJSON.Plug.call/2\",\n    \"line\": \"36\"\n  },\n  \"timestamp\": \"2018-10-18T14:33:33.263Z\"\n}\n```\n\n#","ref":"readme.html#googlecloudlogger","title":"GoogleCloudLogger - Overview","type":"extras"},{"doc":"Adheres to the [default standard attribute list](https://docs.datadoghq.com/logs/processing/attributes_naming_convention/#default-standard-attribute-list).\n\n```json\n{\n  \"domain\": [\"elixir\"],\n  \"duration\": 3863403,\n  \"http\": {\n    \"url\": \"http://localhost/create-account\",\n    \"status_code\": 200,\n    \"method\": \"GET\",\n    \"referer\": \"http://localhost:4000/login\",\n    \"request_id\": \"http_FlDCOItxeudZJ20AAADD\",\n    \"useragent\": \"Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.66 Safari/537.36\",\n    \"url_details\": {\n      \"host\": \"localhost\",\n      \"port\": 4000,\n      \"path\": \"/create-account\",\n      \"queryString\": \"\",\n      \"scheme\": \"http\"\n    }\n  },\n  \"logger\": {\n    \"thread_name\": \"#PID<0.1042.0>\",\n    \"method_name\": \"Elixir.LoggerJSON.Plug.call/2\"\n  },\n  \"message\": \"\",\n  \"network\": {\n    \"client\": {\n      \"ip\": \"127.0.0.1\"\n    }\n  },\n  \"phoenix\": {\n    \"controller\": \"Elixir.RecognizerWeb.Accounts.UserRegistrationController\",\n    \"action\": \"new\"\n  },\n  \"request_id\": \"http_FlDCOItxeudZJ20AAADD\",\n  \"syslog\": {\n    \"hostname\": [10, 10, 100, 100, 100, 100, 100],\n    \"severity\": \"info\",\n    \"timestamp\": \"2020-12-14T19:16:55.088Z\"\n  }\n}\n```\n\n#","ref":"readme.html#datadoglogger","title":"DatadogLogger - Overview","type":"extras"},{"doc":"You can change this structure by implementing `LoggerJSON.Formatter` behaviour and passing module\nname to `:formatter` config option. Example module can be found in `LoggerJSON.Formatters.GoogleCloudLogger`.\n\n```ex\nconfig :logger_json, :backend,\n  formatter: MyFormatterImplementation\n```","ref":"readme.html#custom-formatters","title":"Custom formatters - Overview","type":"extras"},{"doc":"It's [available on Hex](https://hex.pm/packages/logger_json), the package can be installed as:\n\n1. Add `:logger_json` to your list of dependencies in `mix.exs`:\n\n```ex\ndef deps do\n  [{:logger_json, \"~> 5.1\"}]\nend\n```\n\n2. Set configuration in your `config/config.exs`:\n\n```ex\nconfig :logger_json, :backend,\n  metadata: :all,\n  json_encoder: Jason,\n  formatter: LoggerJSON.Formatters.GoogleCloudLogger\n\n```\n\nSome integrations (for eg. Plug) use `metadata` to log request and response parameters. You can reduce log size by replacing `:all` (which means log all metadata) with a list of the ones that you actually need.\n\nBeware that LoggerJSON always ignores [some metadata keys](https://github.com/Nebo15/logger_json/blob/349c8174886135a02bb16317f76beac89d1aa20d/lib/logger_json.ex#L46), but formatters like `GoogleCloudLogger` and `DatadogLogger` still persist those metadata values into a structured output. This behavior is similar to the default Elixir logger backend.\n\n3. Replace default Logger `:console` back-end with `LoggerJSON`:\n\n```ex\nconfig :logger,\n  backends: [LoggerJSON]\n```\n\n4. Optionally. Log requests and responses by replacing a `Plug.Logger` in your endpoint with a:\n\n```ex\nplug LoggerJSON.Plug\n```\n\n`LoggerJSON.Plug` is configured by default to use `LoggerJSON.Plug.MetadataFormatters.GoogleCloudLogger`.\nYou can replace it with the `:metadata_formatter` config option.\n\n5. Optionally. Use Ecto telemetry for additional metadata:\n\nAttach telemetry handler for Ecto events in `start/2` function in `application.ex`\n\n```ex\n:ok =\n  :telemetry.attach(\n    \"logger-json-ecto\",\n    [:my_app, :repo, :query],\n    &LoggerJSON.Ecto.telemetry_logging_handler/4,\n    :debug\n  )\n```\n\nPrevent duplicate logging of events, by setting `log` configuration option to `false`\n\n```ex\nconfig :my_app, MyApp.Repo,\n  adapter: Ecto.Adapters.Postgres,\n  log: false\n```","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"For dynamically configuring the endpoint, such as loading data\nfrom environment variables or configuration files, LoggerJSON provides\nan `:on_init` option that allows developers to set a module, function\nand list of arguments that is invoked when the endpoint starts.\n\n```ex\nconfig :logger_json, :backend,\n  on_init: {YourApp.Logger, :load_from_system_env, []}\n```","ref":"readme.html#dynamic-configuration","title":"Dynamic configuration - Overview","type":"extras"},{"doc":"You can replace default Jason encoder with other module that supports `encode_to_iodata!/1` function and\nencoding fragments.","ref":"readme.html#encoders-support","title":"Encoders support - Overview","type":"extras"},{"doc":"The docs can be found at [https://hexdocs.pm/logger_json](https://hexdocs.pm/logger_json)","ref":"readme.html#documentation","title":"Documentation - Overview","type":"extras"},{"doc":"Many source code has been taken from original Elixir Logger `:console` back-end source code, so I want to thank all it's authors and contributors.\n\nPart of `LoggerJSON.Plug` module have origins from `plug_logger_json` by @bleacherreport,\noriginally licensed under Apache License 2.0. Part of `LoggerJSON.PlugTest` are from Elixir's Plug licensed under Apache 2.","ref":"readme.html#thanks","title":"Thanks - Overview","type":"extras"},{"doc":"Copyright (c) 2016 Nebo #15\n\nReleased under the MIT License, which can be found in [LICENSE.md](./LICENSE.md).","ref":"readme.html#copyright-and-license","title":"Copyright and License - Overview","type":"extras"}]}